@@ -6,21 +6,24 @@ from omega.cli.spotter import Spotter
 from omega.cli.configuration import Configuration
 
 
-@click.command()
+@click.command(
+    "convert",
+    help="Convert Sigma rules into queries.",
+)
 @click.option(
     "--mapping", "-m",
-    help="Omega mapping file",
+    help="Snyper mapping file",
     required=True,
 )
 @click.argument(
     "input",
-    #type=click.Path(exists=True, path_type=pathlib.Path),
+    required=True,
 )
 def convert(input, mapping):
     """
-    Convert Omega rules into queries. INPUT can be multiple files or directories. This command automatically recurses
-    into directories and converts all files matching the pattern in --file-pattern.
+    Convert Sigma rules into queries.
     """
+
     query = ""
     try:
         with open(mapping, 'r') as stream:
